@@ -53,7 +53,7 @@ def read_version_py(infname):
         if mo:
             return mo.group(1)
 
-def update(pkgname, verfilename, revision_number=False, loud=False, EXE_NAME="darcsver"):
+def update(pkgname, verfilename, revision_number=False, loud=False, abort_if_snapshot=False, EXE_NAME="darcsver"):
     """
     @param revision_number If true, count the total number of patches in all
     history.  If false, count the total number of patches since the most recent
@@ -117,15 +117,26 @@ def update(pkgname, verfilename, revision_number=False, loud=False, EXE_NAME="da
     version_re = re.compile(regexstr)
     last_tag = None
     count_since_last_patch = 0
-    for patch in patches:
-        name = get_text(patch.getElementsByTagName("name")[0].childNodes)
-        m = version_re.match(name)
-        if m:
-            last_tag = m.group(1)
-            last_tag = last_tag.encode("utf-8")
-            break
-        else:
-            count_since_last_patch += 1
+    if abort_if_snapshot:
+        for patch in patches:
+            name = get_text(patch.getElementsByTagName("name")[0].childNodes)
+            m = version_re.match(name)
+            if m:
+                last_tag = m.group(1)
+                last_tag = last_tag.encode("utf-8")
+                break
+            else:
+                sys.exit(0) # because abort_if_snapshot
+    else:
+        for patch in patches:
+            name = get_text(patch.getElementsByTagName("name")[0].childNodes)
+            m = version_re.match(name)
+            if m:
+                last_tag = m.group(1)
+                last_tag = last_tag.encode("utf-8")
+                break
+            else:
+                count_since_last_patch += 1
 
     if not last_tag:
         if os.path.exists(verfilename):
