@@ -10,6 +10,7 @@ class DarcsVer(setuptools.Command):
         ('project-name', None, "name of the project as it appears in the project's release tags (default's the to the distribution name)"),
         ('version-file', None, "path to file into which the version number should be written (defaults to the package directory's _version.py)"),
         ('count-all-patches', None, "If true, count the total number of patches in all history.  If false, count the total number of patches since the most recent release tag."),
+        ('abort-if-snapshot', None, "If true, the if the current version is a snapshot (not a release tag), then immediately exit the process with exit code 0."),
         ('quiet', 'q', "Be quiet (deprecated: use --loud instead)."),
         ('loud', 'v', "Be loud (the default is to be not-loud)."),
         ]
@@ -18,6 +19,7 @@ class DarcsVer(setuptools.Command):
         self.project_name = None
         self.version_file = None
         self.count_all_patches = None
+        self.abort_if_snapshot = None
         self.quiet = None
         self.loud = None
 
@@ -64,10 +66,13 @@ class DarcsVer(setuptools.Command):
 
             self.version_file = os.path.join(packagedir, '_version.py')
 
+        if self.abort_if_snapshot is None:
+            self.abort_if_snapshot=False
+
     def run(self):
         if self.loud and not self.quiet:
             loud = True
         else:
             loud = False
-        (rc, verstr) = darcsvermodule.update(self.project_name, self.version_file, self.count_all_patches, loud=loud, EXE_NAME="setup.py darcsver")
+        (rc, verstr) = darcsvermodule.update(self.project_name, self.version_file, self.count_all_patches, abort_if_snapshot=self.abort_if_snapshot, loud=loud, EXE_NAME="setup.py darcsver")
         self.distribution.metadata.version = verstr
